==> vtigercrm-5.0.3.tgz: vtigercrm/modules/Webmails/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Emails/language/en_us.lang.php,v 1.17 2005/03/28 06:31:38 rank Exp $
 * Description:  Defines the English language pack for the Account module.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Email',
'LBL_MODULE_TITLE'=>'Email: Home',
'LBL_SEARCH_FORM_TITLE'=>'Email Search',
'LBL_LIST_FORM_TITLE'=>'Email List',
'LBL_NEW_FORM_TITLE'=>'Track Email',

'LBL_LIST_SUBJECT'=>'Subject',
'LBL_LIST_CONTACT'=>'Contact',
'LBL_LIST_RELATED_TO'=>'Related to',
'LBL_LIST_DATE'=>'Date Sent',
'LBL_LIST_TIME'=>'Time Sent',
'LBL_MOVE_TO'=>'Move To',
'LBL_DELETE'=>'Delete',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the vtiger_account.",
'LBL_DATE_SENT'=>'Date Sent:',
'LBL_SUBJECT'=>'Subject :',
'LBL_DATE_AND_TIME'=>'Date & Time Sent:',
'LBL_DATE'=>'Date :',
'LBL_TIME'=>'Time Sent:',
'LBL_BODY'=>'Body:',
'LBL_CONTACT_NAME'=>' Contact Name: ',
'LBL_EMAIL'=>'Email:',  
'LBL_COLON'=>':',
'LBL_TO'=>'To :',
'LBL_CHK_MAIL'=>'Check Mail',
'LBL_COMPOSE'=>'Compose',
'LBL_SETTINGS'=>'Incoming MailServer Settings',
'LBL_EMAIL_FOLDERS'=>'Email Folders',
'LBL_INBOX'=>'Inbox',
'LBL_SENT_MAILS'=>'Sent Mails',
'LBL_TRASH'=>'Trash',
'LBL_JUNK_MAILS'=>'Junk Mails',
'LBL_TO_LEADS'=>'To Leads',
'LBL_TO_CONTACTS'=>'To Contacts',
'LBL_TO_ACCOUNTS'=>'To Accounts',
'LBL_MY_MAILS'=>'My Mails',
'LBL_QUAL_CONTACT'=>'Qualified Mails (As Contacts)',
'LBL_MAILS'=>'Mails',
'LBL_QUALIFY_BUTTON'=>'Qualify',
'LBL_REPLY_BUTTON'=>'Reply',
'LBL_FORWARD_BUTTON'=>'Forward',
'LBL_DOWNLOAD_ATTCH_BUTTON'=>'Download Attachments',
'LBL_FROM'=>'From :',
'LBL_CC'=>'cc :',
'LBL_REPLY_TO_SENDER'=>'Reply to Sender',
'LBL_REPLY_ALL'=>'Reply All',
'LBL_SHOW_HIDDEN'=>'Show Hidden Mails',
'LBL_EXPUNGE_MAILBOX'=>'Trim Mailbox',

'NTC_REMOVE_INVITEE'=>'Are you sure you want to remove this recipient from the email?',
'LBL_INVITEE'=>'Recipients',

// Added Fields
// Contacts-SubPanelViewContactsAndUsers.php
'LBL_BULK_MAILS'=>'Bulk Mails',
'LBL_ATTACHMENT'=>'Attachment',
'LBL_UPLOAD'=>'Upload',
'LBL_FILE_NAME'=>'File Name',
'LBL_SEND'=>'Send',

'LBL_EMAIL_TEMPLATES'=>'Email Templates',
'LBL_TEMPLATE_NAME'=>'Template Name',
'LBL_DESCRIPTION'=>'Description',
'LBL_EMAIL_TEMPLATES_LIST'=>'Email Templates  List',
'LBL_EMAIL_INFORMATION'=>'Email Information',




//for v4 release added
'LBL_NEW_LEAD'=>'New Lead',
'LBL_LEAD_TITLE'=>'Leads',

'LBL_NEW_PRODUCT'=>'New Product',
'LBL_PRODUCT_TITLE'=>'Products',
'LBL_NEW_CONTACT'=>'New Contact',
'LBL_CONTACT_TITLE'=>'Contacts',
'LBL_NEW_ACCOUNT'=>'New Account',
'LBL_ACCOUNT_TITLE'=>'Accounts',

// Added vtiger_fields after vtiger4 - Beta
'LBL_USER_TITLE'=>'Users',
'LBL_NEW_USER'=>'New User',

// Added for 4 GA
'LBL_TOOL_FORM_TITLE'=>'Email Tools',
//Added for 4GA
'Date & Time Sent'=>'Date & Time Sent',
'Sales Enity Module'=>'Sales Enity Module',
'Activtiy Type'=>'Activtiy Type',
'Related To'=>'Related To',
'Assigned To'=>'Assigned To',
'Subject'=>'Subject',
'Attachment'=>'Attachment',
'Description'=>'Description',
'Time Start'=>'Time Start',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',

'MESSAGE_CHECK_MAIL_SERVER_NAME'=>'Please Check the Mail Server Name...',
'MESSAGE_CHECK_MAIL_ID'=>'Please Check the Email Id of "Assigned To" User...',
'MESSAGE_MAIL_HAS_SENT_TO_USERS'=>'Mail has been sent to the following User(s) :',
'MESSAGE_MAIL_HAS_SENT_TO_CONTACTS'=>'Mail has been sent to the following Contact(s) :',
'MESSAGE_MAIL_ID_IS_INCORRECT'=>'Mail Id is incorrect. Please Check this Mail Id...',
'MESSAGE_ADD_USER_OR_CONTACT'=>'Please Add any User(s) or Contact(s)...',
'MESSAGE_MAIL_SENT_SUCCESSFULLY'=>' Mail(s) sent successfully!',

// Added for web mail post 4.0.1 release
'LBL_FETCH_WEBMAIL'=>'Fetch Web Mail',
//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'All',
'MESSAGE_CONTACT_NOT_WANT_MAIL'=>'This Contact does not want to receive mails.',
'LBL_WEBMAILS_TITLE'=>'WebMails',
'LBL_EMAILS_TITLE'=>'Email',
'LBL_MAIL_CONNECT_ERROR_INFO'=>'Error connecting mail server!<br> Check in My Accounts->List Mail Server -> List Mail Account',
// Added for 5.0.3 release
'LBL_MAIL_CONNECT_ERROR'=>'Could not connect to the mail server. Please check the mail server details',
'IN_REPLY_TO_THE_MESSAGE' => 'In reply to the message sent by ',
'LBL_CLICK_HERE' => 'Click Here ',
'LBL_GOTO_EMAILS_MODULE' => ' go to Email module',
'LBL_NO_EMAILS'=>'No Email In This Folder',
'LBL_MOVE_TO'=>'Move To...',
'LBL_DEL'=>'Del ',
'LABEL_FROM'=>'From',
'LBL_INFO'=>'Info',
'LABEL_DATE'=>'Date',
'LBL_NO_IFRAMES_SUPPORTED'=>'No Iframes supported',
'LBL_EMAIL_ATTACHMENTS'=>'Email Attachments:',
'LBL_ALLMAILS'=>'Email',
'LBL_TO_USERS'=>'To Users',
'LBL_TO_GROUPS'=>'To Groups',
'SUBJECT' => 'Subject',
'BODY' => 'Body',
'TO' => 'To:',
'CC' => 'CC:',
'BCC' => 'BCC:',
'FROM' => 'From:',
'IN'=>'in',
'ADD_FOLDER' => 'Add Folder[X]',
//Added for 5.0.3
'LBL_LOADING_IMAGE' => 'Loading Image',
'LBL_ENABLE_IMAP_SUPPORT' => 'Please enable the IMAP support in php to run this module',
);
?>

==> vtigercrm-5.0.4p0.tgz: vtigercrm/modules/Webmails/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Emails/language/en_us.lang.php,v 1.17 2005/03/28 06:31:38 rank Exp $
 * Description:  Defines the English language pack for the Account module.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Email',
'LBL_MODULE_TITLE'=>'Email: Home',
'LBL_SEARCH_FORM_TITLE'=>'Email Search',
'LBL_LIST_FORM_TITLE'=>'Email List',
'LBL_NEW_FORM_TITLE'=>'Track Email',

'LBL_LIST_SUBJECT'=>'Subject',
'LBL_LIST_CONTACT'=>'Contact',
'LBL_LIST_RELATED_TO'=>'Related to',
'LBL_LIST_DATE'=>'Date Sent',
'LBL_LIST_TIME'=>'Time Sent',
'LBL_MOVE_TO'=>'Move To',
'LBL_DELETE'=>'Delete',

'ERR_DELETE_RECORD'=>"A record number must be specified to delete the vtiger_account.",
'LBL_DATE_SENT'=>'Date Sent:',
'LBL_SUBJECT'=>'Subject :',
'LBL_DATE_AND_TIME'=>'Date & Time Sent:',
'LBL_DATE'=>'Date :',
'LBL_TIME'=>'Time Sent:',
'LBL_BODY'=>'Body:',
'LBL_CONTACT_NAME'=>' Contact Name: ',
'LBL_EMAIL'=>'Email:',  
'LBL_COLON'=>':',
'LBL_TO'=>'To :',
'LBL_CHK_MAIL'=>'Check Mail',
'LBL_COMPOSE'=>'Compose',
'LBL_SETTINGS'=>'Incoming MailServer Settings',
'LBL_EMAIL_FOLDERS'=>'Email Folders',
'LBL_INBOX'=>'Inbox',
'LBL_SENT_MAILS'=>'Sent Mails',
'LBL_TRASH'=>'Trash',
'LBL_JUNK_MAILS'=>'Junk Mails',
'LBL_TO_LEADS'=>'To Leads',
'LBL_TO_CONTACTS'=>'To Contacts',
'LBL_TO_ACCOUNTS'=>'To Accounts',
'LBL_MY_MAILS'=>'My Mails',
'LBL_QUAL_CONTACT'=>'Qualified Mails (As Contacts)',
'LBL_MAILS'=>'Mails',
'LBL_QUALIFY_BUTTON'=>'Qualify',
'LBL_REPLY_BUTTON'=>'Reply',
'LBL_FORWARD_BUTTON'=>'Forward',
'LBL_DOWNLOAD_ATTCH_BUTTON'=>'Download Attachments',
'LBL_FROM'=>'From :',
'LBL_CC'=>'cc :',
'LBL_REPLY_TO_SENDER'=>'Reply to Sender',
'LBL_REPLY_ALL'=>'Reply All',
'LBL_SHOW_HIDDEN'=>'Show Hidden Mails',
'LBL_EXPUNGE_MAILBOX'=>'Trim Mailbox',

'NTC_REMOVE_INVITEE'=>'Are you sure you want to remove this recipient from the email?',
'LBL_INVITEE'=>'Recipients',

// Added Fields
// Contacts-SubPanelViewContactsAndUsers.php
'LBL_BULK_MAILS'=>'Bulk Mails',
'LBL_ATTACHMENT'=>'Attachment',
'LBL_UPLOAD'=>'Upload',
'LBL_FILE_NAME'=>'File Name',
'LBL_SEND'=>'Send',

'LBL_EMAIL_TEMPLATES'=>'Email Templates',
'LBL_TEMPLATE_NAME'=>'Template Name',
'LBL_DESCRIPTION'=>'Description',
'LBL_EMAIL_TEMPLATES_LIST'=>'Email Templates  List',
'LBL_EMAIL_INFORMATION'=>'Email Information',




//for v4 release added
'LBL_NEW_LEAD'=>'New Lead',
'LBL_LEAD_TITLE'=>'Leads',

'LBL_NEW_PRODUCT'=>'New Product',
'LBL_PRODUCT_TITLE'=>'Products',
'LBL_NEW_CONTACT'=>'New Contact',
'LBL_CONTACT_TITLE'=>'Contacts',
'LBL_NEW_ACCOUNT'=>'New Account',
'LBL_ACCOUNT_TITLE'=>'Accounts',

// Added vtiger_fields after vtiger4 - Beta
'LBL_USER_TITLE'=>'Users',
'LBL_NEW_USER'=>'New User',

// Added for 4 GA
'LBL_TOOL_FORM_TITLE'=>'Email Tools',
//Added for 4GA
'Date & Time Sent'=>'Date & Time Sent',
'Sales Enity Module'=>'Sales Enity Module',
'Activtiy Type'=>'Activtiy Type',
'Related To'=>'Related To',
'Assigned To'=>'Assigned To',
'Subject'=>'Subject',
'Attachment'=>'Attachment',
'Description'=>'Description',
'Time Start'=>'Time Start',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',

'MESSAGE_CHECK_MAIL_SERVER_NAME'=>'Please Check the Mail Server Name...',
'MESSAGE_CHECK_MAIL_ID'=>'Please Check the Email Id of "Assigned To" User...',
'MESSAGE_MAIL_HAS_SENT_TO_USERS'=>'Mail has been sent to the following User(s) :',
'MESSAGE_MAIL_HAS_SENT_TO_CONTACTS'=>'Mail has been sent to the following Contact(s) :',
'MESSAGE_MAIL_ID_IS_INCORRECT'=>'Mail Id is incorrect. Please Check this Mail Id...',
'MESSAGE_ADD_USER_OR_CONTACT'=>'Please Add any User(s) or Contact(s)...',
'MESSAGE_MAIL_SENT_SUCCESSFULLY'=>' Mail(s) sent successfully!',

// Added for web mail post 4.0.1 release
'LBL_FETCH_WEBMAIL'=>'Fetch Web Mail',
//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'All',
'MESSAGE_CONTACT_NOT_WANT_MAIL'=>'This Contact does not want to receive mails.',
'LBL_WEBMAILS_TITLE'=>'WebMails',
'LBL_EMAILS_TITLE'=>'Email',
'LBL_MAIL_CONNECT_ERROR_INFO'=>'Error connecting mail server!<br> Check in My Accounts->List Mail Server -> List Mail Account',
// Added for 5.0.3 release
'LBL_MAIL_CONNECT_ERROR'=>'Could not connect to the mail server. Please check the mail server details',
'IN_REPLY_TO_THE_MESSAGE' => 'In reply to the message sent by ',
'LBL_CLICK_HERE' => 'Click Here ',
'LBL_GOTO_EMAILS_MODULE' => ' go to Email module',
'LBL_NO_EMAILS'=>'No Email In This Folder',
'LBL_MOVE_TO'=>'Move To...',
'LBL_DEL'=>'Del ',
'LABEL_FROM'=>'From',
'LBL_INFO'=>'Info',
'LABEL_DATE'=>'Date',
'LBL_NO_IFRAMES_SUPPORTED'=>'No Iframes supported',
'LBL_EMAIL_ATTACHMENTS'=>'Email Attachments:',
'LBL_ALLMAILS'=>'Email',
'LBL_TO_USERS'=>'To Users',
'LBL_TO_GROUPS'=>'To Groups',
'SUBJECT' => 'Subject',
'BODY' => 'Body',
'TO' => 'To:',
'CC' => 'CC:',
'BCC' => 'BCC:',
'FROM' => 'From:',
'IN'=>'in',
'ADD_FOLDER' => 'Add Folder[X]',
//Added for 5.0.3
'LBL_LOADING_IMAGE' => 'Loading Image',
'LBL_ENABLE_IMAP_SUPPORT' => 'Please enable the IMAP support in php to run this module',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CONFIGURE_MAIL_SETTINGS'=>'Please configure your mail settings',
'LBL_PLEASE'=>'Please',
'LBL_HERE'=>'Here',
);
?>
